@@ -243,7 +243,9 @@ struct rewrite_session {
 	Avlnode                        *ls_vars;
 #ifdef USE_REWRITE_LDAP_PVT_THREADS
 	ldap_pvt_thread_rdwr_t          ls_vars_mutex;
+	ldap_pvt_thread_mutex_t		ls_mutex;
 #endif /* USE_REWRITE_LDAP_PVT_THREADS */
+	int				ls_count;
 };
 
 /*
