@@ -1,5 +1,5 @@
 /* tools.c - tools for slap tools */
-/* $OpenLDAP: pkg/ldap/servers/slapd/back-bdb/tools.c,v 1.31.2.6 2003/03/03 17:10:07 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/back-bdb/tools.c,v 1.31.2.7 2003/03/13 03:35:26 kurt Exp $ */
 /*
  * Copyright 1998-2003 The OpenLDAP Foundation, All Rights Reserved.
  * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
@@ -182,10 +182,10 @@ int bdb_tool_next_id(
 		} else if ( hole ) {
 			if ( nholes == nhmax - 1 ) {
 				if ( holes == hbuf ) {
-					holes = malloc( nhmax * sizeof(ID) * 2 );
+					holes = ch_malloc( nhmax * sizeof(ID) * 2 );
 					AC_MEMCPY( holes, hbuf, sizeof(hbuf) );
 				} else {
-					holes = realloc( holes, nhmax * sizeof(ID) * 2 );
+					holes = ch_realloc( holes, nhmax * sizeof(ID) * 2 );
 				}
 				nhmax *= 2;
 			}
