@@ -1,4 +1,4 @@
-/* $OpenLDAP: pkg/ldap/servers/slapd/daemon.c,v 1.211.2.19 2003/03/06 19:11:23 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/daemon.c,v 1.211.2.20 2003/03/12 20:58:48 kurt Exp $ */
 /*
  * Copyright 1998-2003 The OpenLDAP Foundation, All Rights Reserved.
  * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
@@ -107,7 +107,7 @@ void slapd_slp_init( const char* urls ) {
 		if( strcmp( slapd_srvurls[i], "ldap:///" ) == 0) {
 			char *host = ldap_pvt_get_fqdn( NULL );
 			if ( host != NULL ) {
-				slapd_srvurls[i] = (char *) realloc( slapd_srvurls[i],
+				slapd_srvurls[i] = (char *) ch_realloc( slapd_srvurls[i],
 					strlen( host ) +
 					sizeof( LDAP_SRVTYPE_PREFIX ) );
 				strcpy( lutil_strcopy(slapd_srvurls[i],
@@ -119,7 +119,7 @@ void slapd_slp_init( const char* urls ) {
 		} else if ( strcmp( slapd_srvurls[i], "ldaps:///" ) == 0) {
 			char *host = ldap_pvt_get_fqdn( NULL );
 			if ( host != NULL ) {
-				slapd_srvurls[i] = (char *) realloc( slapd_srvurls[i],
+				slapd_srvurls[i] = (char *) ch_realloc( slapd_srvurls[i],
 					strlen( host ) +
 					sizeof( LDAPS_SRVTYPE_PREFIX ) );
 				strcpy( lutil_strcopy(slapd_srvurls[i],
@@ -1613,7 +1613,7 @@ slapd_daemon_task(
 #ifdef SLAPD_RLOOKUPS
 				if ( use_reverse_lookup ) {
 					char *herr;
-					if (ldap_pvt_get_hname( &from, len, hbuf,
+					if (ldap_pvt_get_hname( (const struct sockaddr *)&from, len, hbuf,
 						sizeof(hbuf), &herr ) == 0) {
 						ldap_pvt_str2lower( hbuf );
 						dnsname = hbuf;
